gracetools.detach_grace_containers_attached_to_leaf
===================================================

.. autofunction:: abjad.tools.gracetools.detach_grace_containers_attached_to_leaf.detach_grace_containers_attached_to_leaf
